@@ -278,6 +278,8 @@ class GitLabFormCore(object):
                 logging.error("+++ Error while processing '%s'", project_and_group)
                 traceback.print_exc()
 
+            logging.debug('@ [%s/%s] FINISHED Processing: %s', i, len(projects_and_groups), project_and_group)
+
     @if_in_config_and_not_skipped
     def process_project_settings(self, project_and_group, configuration):
         project_settings = configuration['project_settings']
@@ -564,6 +566,19 @@ class GitLabFormCore(object):
                 logging.debug("Deleting service '%s'", service)
                 self.gl.delete_service(project_and_group, service)
             else:
+
+                if configuration.get('services|' + service + '|recreate'):
+                    try:
+                        # try to workaround issues like https://github.com/egnyte/gitlabform/issues/69 :
+                        # if service change does not work, then try to recreate it each time
+                        self.gl.get_service(project_and_group, service)
+                        logging.debug("Deleting service '%s' first as a workaround for GitLab issues", service)
+                        self.gl.delete_service(project_and_group, service)
+                    except NotFoundException:
+                        logging.debug("Service '%s' is not configured yet.", service)
+
+                    del configuration['services'][service]['recreate']
+
                 logging.debug("Setting service '%s'", service)
                 self.gl.set_service(project_and_group, service, configuration['services'][service])
 
